@@ -12,6 +12,7 @@
 #include <QSortFilterProxyModel>
 #include <QStandardItemModel>
 #include <QVBoxLayout>
+#include <TextAddonsWidgets/LineEditCatchReturnKey>
 using namespace TextTranslator;
 
 TranslatorConfigureLanguageListWidget::TranslatorConfigureLanguageListWidget(const QString &labelText, QWidget *parent)
@@ -43,6 +44,7 @@ TranslatorConfigureLanguageListWidget::TranslatorConfigureLanguageListWidget(con
     mLanguageListWidget->setObjectName(QStringLiteral("mLanguageListWidget"));
     mainLayout->addWidget(mLanguageListWidget);
     mLanguageListWidget->setModel(filterProxyModel);
+    new TextAddonsWidgets::LineEditCatchReturnKey(mListSearchLine, this);
 }
 
 TranslatorConfigureLanguageListWidget::~TranslatorConfigureLanguageListWidget() = default;
